==> qtmclock_src-0.1.0.tar.gz: qtmclock_src-0.1.0/qtmclock_config/qtmclock_config_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ja_JP">
<defaultcodec></defaultcodec>
<context>
    <name>QLabel</name>
    <message>
        <location filename="../qtmclock/ThemeClockDraw.cpp" line="60"/>
        <source>Drop theme file in this form.</source>
        <translation>テーマファイルを、このフォームにドロップして下さい.</translation>
    </message>
</context>
<context>
    <name>ReleaseDialog</name>
    <message>
        <location filename="ReleaseDialogForm.ui" line="13"/>
        <source>Theme Config: Release</source>
        <translation>Theme Config: Release</translation>
    </message>
    <message>
        <location filename="ReleaseDialogForm.ui" line="26"/>
        <source>Theme File</source>
        <translation>出力ファイル名</translation>
    </message>
    <message>
        <location filename="ReleaseDialogForm.ui" line="62"/>
        <source>RRDA Key</source>
        <translation>RRDA キー</translation>
    </message>
</context>
<context>
    <name>ThemeConfigWindow</name>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="18"/>
        <source>Theme Config</source>
        <translation>Theme Config</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="248"/>
        <source>long hand</source>
        <translation>長針</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="225"/>
        <source>base</source>
        <translation>ベース</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="240"/>
        <source>short hand</source>
        <translation>短針</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="256"/>
        <source>second hand</source>
        <translation>秒針</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="265"/>
        <source>digital character</source>
        <translation>デジタル文字</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="516"/>
        <source>toolbar</source>
        <translation>ツールバー</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="272"/>
        <source>hour</source>
        <translation>時</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="296"/>
        <source>minute</source>
        <translation>分</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="312"/>
        <source>second</source>
        <translation>秒</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="328"/>
        <source>AM/PM</source>
        <translation>AM/PM</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="288"/>
        <source>colon</source>
        <translation>コロン</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="215"/>
        <source>Node</source>
        <translation>項目</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="220"/>
        <source>Value</source>
        <translation>画像</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="534"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1254"/>
        <source>Create a new config file.</source>
        <translation>設定ファイルの新規作成.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="546"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1258"/>
        <source>Open an exist config file.</source>
        <translation>設定ファイルを開く.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="558"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1262"/>
        <source>Save the config file to disk.</source>
        <translation>設定ファイルの保存.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="128"/>
        <source>hands&apos;s center are samve.</source>
        <translation>長針、短針、秒針の中心を揃える.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="233"/>
        <source>analog parts</source>
        <translation>アナログ部品</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="40"/>
        <source>Play / Stop</source>
        <translation>再生 / 停止</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="469"/>
        <source>File (&amp;F)</source>
        <translation>ファイル (&amp;F)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="482"/>
        <source>Edit (&amp;E)</source>
        <translation>編集 (&amp;E)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="488"/>
        <source>Help (&amp;H)</source>
        <translation>ヘルプ (&amp;H)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1253"/>
        <source>New</source>
        <translation>新規作成</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1257"/>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1261"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="563"/>
        <source>Release (&amp;R)</source>
        <translation>リリース (&amp;R)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="568"/>
        <source>Exit (&amp;Q)</source>
        <translation>終了 (&amp;Q)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="571"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="576"/>
        <source>Save as</source>
        <translation>名前を付けて保存</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="581"/>
        <source>Preview (&amp;R)</source>
        <translation>プレビュー (&amp;R)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="584"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="589"/>
        <source>About (&amp;A)</source>
        <translation>このアプリケーションについて (&amp;A)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="279"/>
        <source>h2</source>
        <translation>位置 (1の位)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="303"/>
        <source>m2</source>
        <translation>位置 (100 の位)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="319"/>
        <source>s2</source>
        <translation>位置 (1の位)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="138"/>
        <source>blink digital colon.</source>
        <translation>デジタル文字のコロン表示を点滅させる.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="158"/>
        <source>show digital second.</source>
        <translation>デジタル文字の秒を表示する.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1336"/>
        <source>Open archive list file.</source>
        <translation>設定ファイルを開く.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1378"/>
        <source>archive list (*.txt)</source>
        <translation>設定ファイル (*.txt)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1376"/>
        <source>Save archive list file.</source>
        <translation>設定ファイルの保存.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="531"/>
        <source>New (&amp;N)</source>
        <translation>新規作成 (&amp;N)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="543"/>
        <source>Open (&amp;O)</source>
        <translation>開く (&amp;O)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="555"/>
        <source>Save (&amp;S)</source>
        <translation>保存 (&amp;S)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="438"/>
        <source>Parts image</source>
        <translation>部品画像の更新</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="448"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="148"/>
        <source>show analog second.</source>
        <translation>秒針を表示する.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1583"/>
        <source>Open parts file.</source>
        <translation>部品ファイルを開く.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1585"/>
        <source>parts file (*.png)</source>
        <translation>部品ファイル (*.png)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1457"/>
        <source>About qtmclock_config</source>
        <translation>qtmclock_config について</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1461"/>
        <source>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Theme making tool for Qtmclock.&lt;/p&gt;&lt;p&gt;Report bugs to &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</source>
        <translation>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Qtmclock 用のテーマ作成ツール&lt;/p&gt;&lt;p&gt;バグの報告先 &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="108"/>
        <source>Clock</source>
        <translation>時計</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="119"/>
        <source>Clock Settings</source>
        <translation>描画設定</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="180"/>
        <source>Calendar</source>
        <translation>カレンダー</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="186"/>
        <source>Calendar Settings</source>
        <translation>描画設定</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="337"/>
        <source>calendar</source>
        <translation>カレンダー</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="351"/>
        <source>month</source>
        <translation>月</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="375"/>
        <source>day</source>
        <translation>日</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="408"/>
        <source>day of the week</source>
        <translation>曜日</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="195"/>
        <source>show month.</source>
        <translation>月を表示する.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="344"/>
        <source>number</source>
        <translation>数値</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="366"/>
        <source>month_separator</source>
        <translation>区切り文字</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="382"/>
        <source>c_d2</source>
        <translation>位置 (1 の位)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="390"/>
        <source>day_separator</source>
        <translation>区切り文字</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="400"/>
        <source>separator</source>
        <translation>区切り文字</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="358"/>
        <source>c_m2</source>
        <translation>位置 (1 の位)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="417"/>
        <source>additional</source>
        <translation>追加部品</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="424"/>
        <source>near</source>
        <translation>手前</translation>
    </message>
</context>
</TS>

==> qtmclock_src-0.1.1.tar.gz: qtmclock_src-0.1.1/qtmclock_config/qtmclock_config_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ja_JP">
<defaultcodec></defaultcodec>
<context>
    <name>PatternRegisterWidgetForm</name>
    <message>
        <location filename="PatternRegisterWidgetForm.ui" line="18"/>
        <source>PatternRegister</source>
        <translation>パターン登録</translation>
    </message>
    <message>
        <location filename="PatternRegisterWidgetForm.ui" line="24"/>
        <source>Pattern_000</source>
        <translation>Pattern_000</translation>
    </message>
    <message>
        <location filename="PatternRegisterWidgetForm.ui" line="30"/>
        <source>Probability</source>
        <translation>発生確率</translation>
    </message>
    <message>
        <location filename="PatternRegisterWidgetForm.ui" line="70"/>
        <source>/ sec</source>
        <translation>/ 秒</translation>
    </message>
    <message>
        <location filename="PatternRegisterWidgetForm.ui" line="136"/>
        <source>Pattern</source>
        <translation>パターン</translation>
    </message>
    <message>
        <location filename="PatternRegisterWidgetForm.ui" line="156"/>
        <source>Preview</source>
        <translation>プレビュー</translation>
    </message>
    <message>
        <location filename="PatternRegisterWidgetForm.ui" line="95"/>
        <source>Cycle</source>
        <translation>再生周期</translation>
    </message>
    <message>
        <location filename="PatternRegisterWidgetForm.ui" line="114"/>
        <source>msec</source>
        <translation>ミリ秒</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <location filename="../qtmclock/ThemeClockDraw.cpp" line="56"/>
        <source>Drop theme file in this form.</source>
        <translation>テーマファイルを、このフォームにドロップして下さい.</translation>
    </message>
</context>
<context>
    <name>ReleaseDialog</name>
    <message>
        <location filename="ReleaseDialogForm.ui" line="13"/>
        <source>Theme Config: Release</source>
        <translation>Theme Config: Release</translation>
    </message>
    <message>
        <location filename="ReleaseDialogForm.ui" line="26"/>
        <source>Theme File</source>
        <translation>出力ファイル名</translation>
    </message>
    <message>
        <location filename="ReleaseDialogForm.ui" line="62"/>
        <source>RRDA Key</source>
        <translation>RRDA キー</translation>
    </message>
</context>
<context>
    <name>ThemeConfigWindow</name>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="18"/>
        <source>Theme Config</source>
        <translation>Theme Config</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="273"/>
        <source>long hand</source>
        <translation>長針</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="250"/>
        <source>base</source>
        <translation>ベース</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="265"/>
        <source>short hand</source>
        <translation>短針</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="281"/>
        <source>second hand</source>
        <translation>秒針</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="290"/>
        <source>digital character</source>
        <translation>デジタル文字</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="590"/>
        <source>toolbar</source>
        <translation>ツールバー</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="297"/>
        <source>hour</source>
        <translation>時</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="321"/>
        <source>minute</source>
        <translation>分</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="337"/>
        <source>second</source>
        <translation>秒</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="353"/>
        <source>AM/PM</source>
        <translation>AM/PM</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="313"/>
        <source>colon</source>
        <translation>コロン</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="240"/>
        <source>Node</source>
        <translation>項目</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="245"/>
        <source>Value</source>
        <translation>画像</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="608"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1453"/>
        <source>Create a new config file.</source>
        <translation>設定ファイルの新規作成.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="620"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1457"/>
        <source>Open an exist config file.</source>
        <translation>設定ファイルを開く.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="632"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1461"/>
        <source>Save the config file to disk.</source>
        <translation>設定ファイルの保存.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="146"/>
        <source>hands&apos;s center are samve.</source>
        <translation>長針、短針、秒針の中心を揃える.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="258"/>
        <source>analog parts</source>
        <translation>アナログ部品</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="40"/>
        <source>Play / Stop</source>
        <translation>再生 / 停止</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="543"/>
        <source>File (&amp;F)</source>
        <translation>ファイル (&amp;F)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="556"/>
        <source>Edit (&amp;E)</source>
        <translation>編集 (&amp;E)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="562"/>
        <source>Help (&amp;H)</source>
        <translation>ヘルプ (&amp;H)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1452"/>
        <source>New</source>
        <translation>新規作成</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1456"/>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1460"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="637"/>
        <source>Release (&amp;R)</source>
        <translation>リリース (&amp;R)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="642"/>
        <source>Exit (&amp;Q)</source>
        <translation>終了 (&amp;Q)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="645"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="650"/>
        <source>Save as</source>
        <translation>名前を付けて保存</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="655"/>
        <source>Preview (&amp;R)</source>
        <translation>プレビュー (&amp;R)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="658"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="663"/>
        <source>About (&amp;A)</source>
        <translation>このアプリケーションについて (&amp;A)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="304"/>
        <source>h2</source>
        <translation>位置 (1の位)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="328"/>
        <source>m2</source>
        <translation>位置 (100 の位)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="344"/>
        <source>s2</source>
        <translation>位置 (1の位)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="163"/>
        <source>blink digital colon.</source>
        <translation>デジタル文字のコロンを点滅させる.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="183"/>
        <source>show digital second.</source>
        <translation>デジタル文字の秒を表示する.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1544"/>
        <source>Open archive list file.</source>
        <translation>設定ファイルを開く.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1586"/>
        <source>archive list (*.txt)</source>
        <translation>設定ファイル (*.txt)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1584"/>
        <source>Save archive list file.</source>
        <translation>設定ファイルの保存.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="605"/>
        <source>New (&amp;N)</source>
        <translation>新規作成 (&amp;N)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="617"/>
        <source>Open (&amp;O)</source>
        <translation>開く (&amp;O)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="629"/>
        <source>Save (&amp;S)</source>
        <translation>保存 (&amp;S)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="471"/>
        <source>Parts image</source>
        <translation>部品画像の更新</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="481"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="173"/>
        <source>show analog second.</source>
        <translation>秒針を表示する.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1827"/>
        <source>Open parts file.</source>
        <translation>部品ファイルを開く.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1829"/>
        <source>parts file (*.png)</source>
        <translation>部品ファイル (*.png)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1665"/>
        <source>About qtmclock_config</source>
        <translation>qtmclock_config について</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="1669"/>
        <source>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Theme making tool for Qtmclock.&lt;/p&gt;&lt;p&gt;Report bugs to &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</source>
        <translation>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Qtmclock 用のテーマ作成ツール&lt;/p&gt;&lt;p&gt;バグの報告先 &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="126"/>
        <source>Clock</source>
        <translation>時計</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="137"/>
        <source>Clock Settings</source>
        <translation>描画設定</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="205"/>
        <source>Calendar</source>
        <translation>カレンダー</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="211"/>
        <source>Calendar Settings</source>
        <translation>描画設定</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="362"/>
        <source>calendar</source>
        <translation>カレンダー</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="376"/>
        <source>month</source>
        <translation>月</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="400"/>
        <source>day</source>
        <translation>日</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="433"/>
        <source>day of the week</source>
        <translation>曜日</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="220"/>
        <source>show month.</source>
        <translation>月を表示する.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="369"/>
        <source>number</source>
        <translation>数値</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="391"/>
        <source>month_separator</source>
        <translation>区切り文字</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="407"/>
        <source>c_d2</source>
        <translation>位置 (1 の位)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="415"/>
        <source>day_separator</source>
        <translation>区切り文字</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="425"/>
        <source>separator</source>
        <translation>区切り文字</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="383"/>
        <source>c_m2</source>
        <translation>位置 (1 の位)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="442"/>
        <source>additional</source>
        <translation>追加部品</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="449"/>
        <source>near</source>
        <translation>手前</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="101"/>
        <source>Placement</source>
        <translation>配置</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="458"/>
        <source>animation</source>
        <translation>アニメーション</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="501"/>
        <source>Animation</source>
        <translation>アニメーション</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="156"/>
        <source>show digital colon.</source>
        <translation>デジタル文字のコロンを表示する.</translation>
    </message>
</context>
</TS>
